@@ -24,7 +24,7 @@ import App from '../common/app';
 const routes = (
 
     <Router history={browserHistory}>
-    <Route path="/client/product" component={App}>
+    <Route path="/"<%=data.endName%>"/"<%=data.moduleName%>"" component={App}>
 
     <Route path="home" component={Home} />
     <Route path="list" component={List} />
